#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <math.h>
#include <libharkio3.h>

#define  PATH_LEN     1024     // file path 最大長




void help(void)
{
    printf("                                                                    \n");
    printf("                                                                    \n");
    printf("[NAME:]                                                             \n");
    printf("  harktoolcli-conv-tf                                               \n");
    printf("                                                                    \n");
    printf("[Description:]                                                      \n");
    printf("  This command converts transfer function files in libharkio2-style \n");
    printf("  format to a new libharkio3-style format.                          \n");
    printf("  This command takes an old-style transfer function for localization\n");
    printf("  and/or one for separation. Then, it generastes a new-style file   \n");
    printf("  format in zip files. If both transfer functions for localization  \n");
    printf("  and separation are given, the command generates one zip file that \n");
    printf("  contains both two transfer functions.                             \n");
    printf("                                                                    \n");
    printf("  If only a transfer function for localization is given, the        \n");
    printf("  generated zip file has .mat files in its localization/ directory, \n");
    printf("  and the separation/ directory is empty. If both transfer functions\n");
    printf("  are given, both localization/ and separation/ directories have    \n");
    printf("  corresponding .mat files.                                         \n");
    printf("                                                                    \n");
    printf("[Usage :]                                                           \n");
    printf("  harktoolcli-conv-tf [options]                                     \n");
    printf("                                                                    \n");
    printf("[options]                                                           \n");
    printf("  -l : Localization transfer file(Binary) or NULL  (-l loc.tf)      \n");
    printf("  -s : Separation transfer file(Binary)   or NULL  (-s sep.tf )     \n");
    printf("  -o : output transfer file(zip file)              (-o output.zip)  \n");
    printf("  -l and -s are optional.                                           \n");
    printf("                                                                    \n");
    printf("                                                                    \n");
}









int main(int argc, char **argv)
{

    int option;
    char *loctfpath = NULL;
    char *septfpath= NULL;
    char *outfile= NULL;
    char *whatisthis= "transfer function";

    harkio_TransferFunction *tf = NULL;


    //argument check
    if (argc <= 1) {
        harkio_Log_printf(harkio_Log_Error , "argument error!!");
        help();
        exit(EXIT_FAILURE);
    }

    // help
    if (strcmp(argv[1] , "--help") == 0) {
        help();
        exit(EXIT_SUCCESS);
    }

    // parse option
    while ((option = getopt(argc, argv, "o:l:s:")) != -1) {
        switch (option) {
        case 'l':
            loctfpath = (char *)malloc(strlen(optarg) + 1);
            memset(loctfpath  , '\0' , strlen(optarg) + 1);
            memcpy(loctfpath , optarg, strlen(optarg));

            break;

        case 's':
            septfpath = (char *)malloc(strlen(optarg) + 1);
            memset(septfpath  , '\0' , strlen(optarg) + 1);
            memcpy(septfpath , optarg, strlen(optarg));
            break;

        case 'o':
            outfile = (char *)malloc(strlen(optarg) + 1);
            memset(outfile  , '\0' , strlen(optarg) + 1);
            memcpy(outfile , optarg, strlen(optarg));
            break;

        case '?':
            help();
            exit(EXIT_FAILURE);
        }
    }



    if (loctfpath) printf("loctfpath=%s\n",loctfpath);
    if (septfpath) printf("septfpath=%s\n",septfpath);

    // result = libharkio3_TransferFunction_readlibhakio2( &tf , loctfpath ,  septfpath);
    tf = harkio_Compat_TransferFunction_readlibharkio2(loctfpath, septfpath);


    if (tf == NULL) {
        harkio_TransferFunction_delete(&tf);
        harkio_Log_printf(harkio_Log_Error , "harkio_Compat_TransferFunction_readlibharkio2 error");
        exit(EXIT_FAILURE);
    }



    //write zip file
    harkio_TransferFunction_write(tf , outfile , whatisthis);


    fprintf(stderr, "SUCCESS\n");
    fprintf(stderr, " output file : %s\n",outfile);

    harkio_TransferFunction_delete(&tf);
    if (loctfpath !=NULL) free(loctfpath);
    if (septfpath !=NULL) free(septfpath);
    if (outfile   !=NULL) free(outfile);

    exit(EXIT_SUCCESS);


}//func end


